@@ -194,7 +194,10 @@ static void
 unlock (void)
 {
 	if (! --lock_count) {
-		database->sync (database, 0);
+		if (!database)
+			init ();
+		if (database)
+			database->sync (database, 0);
 		rmdir (lock_directory);
 	}
 }
@@ -387,7 +390,6 @@ metadata_remove (const char *space, const char *object, const char *key)
 		if (p != end) {
 			/* Remove it.  */
 			int l = strlen (p) + 1;
-
 			if ((int) value.size == l) {
 				/* Remove entry entirely.  */
 				database->del (database, &dkey, 0);
@@ -1133,8 +1135,10 @@ worker (const char *from, const char *to, int op)
 	   efficient, but perhaps messier.  */
 
 	keys = gnome_metadata_list (from);
-	if (! keys)
+	if (! keys){
+		unlock ();
 		return 0;
+	}
 
 	for (i = 0; keys[i]; ++i) {
 		int size, r;
