@@ -23,6 +23,7 @@
 enum {
 	ARG_0,
 	ARG_IMAGE,
+	ARG_PIXBUF,
 	ARG_X,
 	ARG_Y,
 	ARG_WIDTH,
@@ -92,6 +93,7 @@ gnome_canvas_image_class_init (GnomeCanvasImageClass *class)
 	parent_class = gtk_type_class (gnome_canvas_item_get_type ());
 
 	gtk_object_add_arg_type ("GnomeCanvasImage::image", GTK_TYPE_GDK_IMLIB_IMAGE, GTK_ARG_READWRITE, ARG_IMAGE);
+	gtk_object_add_arg_type ("GnomeCanvasImage::pixbuf", GTK_TYPE_BOXED, GTK_ARG_WRITABLE, ARG_PIXBUF);
 	gtk_object_add_arg_type ("GnomeCanvasImage::x", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_X);
 	gtk_object_add_arg_type ("GnomeCanvasImage::y", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_Y);
 	gtk_object_add_arg_type ("GnomeCanvasImage::width", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_WIDTH);
@@ -149,8 +151,10 @@ gnome_canvas_image_destroy (GtkObject *object)
 
 	free_pixmap_and_mask (image);
 
-	if (image->pixbuf != NULL)
+	if (image->pixbuf) {
 		art_pixbuf_free (image->pixbuf);
+		image->pixbuf = NULL;
+	}
 
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
@@ -285,6 +289,17 @@ gnome_canvas_image_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		update = TRUE;
 		break;
 
+	case ARG_PIXBUF:
+		/* The pixmap and mask will be freed when the item is reconfigured */
+		if (item->canvas->aa && GTK_VALUE_BOXED (*arg)) {
+			image->im = NULL;
+			if (image->pixbuf != NULL)
+				art_pixbuf_free (image->pixbuf);
+			image->pixbuf = GTK_VALUE_BOXED (*arg);
+		}
+		update = TRUE;
+		break;
+
 	case ARG_X:
 		image->x = GTK_VALUE_DOUBLE (*arg);
 		update = TRUE;
@@ -383,7 +398,7 @@ gnome_canvas_image_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_p
 	image->cwidth = (int) (image->width * affine[0] + 0.5);
 	image->cheight = (int) (image->height * affine[3] + 0.5);
 
-	if (image->im)
+	if (image->im || image->pixbuf)
 		image->need_recalc = TRUE;
 
 #ifdef OLD_XFORM
@@ -407,6 +422,9 @@ gnome_canvas_image_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_p
 	if (image->im) {
 		w = image->im->rgb_width;
 		h = image->im->rgb_height;
+	} else if (image->pixbuf) {
+		w = image->pixbuf->width;
+		h = image->pixbuf->height;
 	} else
 		w = h = 1;
 
@@ -455,14 +473,16 @@ recalc_if_needed (GnomeCanvasImage *image)
 
 	get_bounds (image, &image->item.x1, &image->item.y1, &image->item.x2, &image->item.y2);
 
-	gdk_imlib_render (image->im, image->cwidth, image->cheight);
-
-	image->pixmap = gdk_imlib_move_image (image->im);
-	g_assert (image->pixmap != NULL);
-	image->mask = gdk_imlib_move_mask (image->im);
-
-	if (image->gc)
-		gdk_gc_set_clip_mask (image->gc, image->mask);
+	if (image->im) {
+		gdk_imlib_render (image->im, image->cwidth, image->cheight);
+		
+		image->pixmap = gdk_imlib_move_image (image->im);
+		g_assert (image->pixmap != NULL);
+		image->mask = gdk_imlib_move_mask (image->im);
+		
+		if (image->gc)
+			gdk_gc_set_clip_mask (image->gc, image->mask);
+	}
 
 	image->need_recalc = FALSE;
 }
@@ -541,7 +561,7 @@ dist_to_mask (GnomeCanvasImage *image, int cx, int cy)
 				tx = x + dest.x - cx;
 				ty = y + dest.y - cy;
 
-				dist = hypot(tx, ty);
+				dist = sqrt (tx * tx + ty * ty);
 				if (dist < best)
 					best = dist;
 			}
@@ -595,7 +615,7 @@ gnome_canvas_image_point (GnomeCanvasItem *item, double x, double y,
 	else
 		dy = 0;
 
-	return hypot(dx, dy) / item->canvas->pixels_per_unit;
+	return sqrt (dx * dx + dy * dy) / item->canvas->pixels_per_unit;
 }
 
 static void
@@ -696,7 +716,6 @@ gnome_canvas_image_render      (GnomeCanvasItem *item, GnomeCanvasBuf *buf)
 static ArtPixBuf *
 pixbuf_from_imlib_image (GdkImlibImage *im)
 {
-	ArtPixBuf *pixbuf;
 	art_u8 *pixels;
 	int width, height, rowstride;
 	int x, y;
