@@ -423,7 +423,7 @@ reconfigure_arrows (GnomeCanvasLine *line)
 
 		dx = poly[0] - line->coords[2];
 		dy = poly[1] - line->coords[3];
-		length = hypot(dx, dy);
+		length = sqrt (dx * dx + dy * dy);
 		if (length < GNOME_CANVAS_EPSILON)
 			sin_theta = cos_theta = 0.0;
 		else {
@@ -467,7 +467,7 @@ reconfigure_arrows (GnomeCanvasLine *line)
 
 		dx = poly[0] - coords[0];
 		dy = poly[1] - coords[1];
-		length = hypot(dx, dy);
+		length = sqrt (dx * dx + dy * dy);
 		if (length < GNOME_CANVAS_EPSILON)
 			sin_theta = cos_theta = 0.0;
 		else {
@@ -566,12 +566,17 @@ gnome_canvas_line_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	GnomeCanvasItem *item;
 	GnomeCanvasLine *line;
 	GnomeCanvasPoints *points;
-	GdkColor color;
-	GdkColor *colorp;
+	GdkColor color = { 0, 0, 0, 0, };
+	GdkColor *pcolor;
+	gboolean color_changed;
+	int have_pixel;
 
 	item = GNOME_CANVAS_ITEM (object);
 	line = GNOME_CANVAS_LINE (object);
 
+	color_changed = FALSE;
+	have_pixel = FALSE;
+
 	switch (arg_id) {
 	case ARG_POINTS:
 		points = GTK_VALUE_POINTER (*arg);
@@ -613,37 +618,33 @@ gnome_canvas_line_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_FILL_COLOR:
-		gnome_canvas_get_color (item->canvas, GTK_VALUE_STRING (*arg), &color);
-		line->fill_pixel = color.pixel;
-		if (item->canvas->aa) 
-			line->fill_rgba =
-				((color.red & 0xff00) << 16) |
-				((color.green & 0xff00) << 8) |
-				(color.blue & 0xff00) |
-				0xff;
-		else
-			set_line_gc_foreground (line);
-
-		gnome_canvas_item_request_redraw_svp (item, line->fill_svp);
+		if (GTK_VALUE_STRING (*arg))
+			gdk_color_parse (GTK_VALUE_STRING (*arg), &color);
+		line->fill_rgba = ((color.red & 0xff00) << 16 |
+				   (color.green & 0xff00) << 8 |
+				   (color.blue & 0xff00) |
+				   0xff);
+		color_changed = TRUE;
 		break;
 
 	case ARG_FILL_COLOR_GDK:
-		colorp = (GdkColor *) GTK_VALUE_BOXED (*arg);
-		line->fill_pixel = colorp->pixel;
-		if (item->canvas->aa) 
-			line->fill_rgba = (((colorp->red & 0xff00) << 16) |
-					   ((colorp->green & 0xff00) << 8) |
-					   (colorp->blue & 0xff00) |
-					   0xff);
-		else
-			set_line_gc_foreground (line);
+		pcolor = GTK_VALUE_BOXED (*arg);
+		if (pcolor) {
+			color = *pcolor;
+			gdk_color_context_query_color (item->canvas->cc, &color);
+			have_pixel = TRUE;
+		}
 
-		gnome_canvas_item_request_redraw_svp (item, line->fill_svp);
+		line->fill_rgba = ((color.red & 0xff00) << 16 |
+				   (color.green & 0xff00) << 8 |
+				   (color.blue & 0xff00) |
+				   0xff);
+		color_changed = TRUE;
 		break;
 
 	case ARG_FILL_COLOR_RGBA:
 		line->fill_rgba = GTK_VALUE_UINT (*arg);
-		gnome_canvas_item_request_redraw_svp (item, line->fill_svp);
+		color_changed = TRUE;
 		break;
 
 	case ARG_FILL_STIPPLE:
@@ -690,7 +691,7 @@ gnome_canvas_line_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		gnome_canvas_item_request_update (item);
 #endif
 		break;
-	
+
 	case ARG_LINE_STYLE:
 		line->line_style = GTK_VALUE_ENUM (*arg);
 		set_line_gc_width (line);
@@ -757,6 +758,19 @@ gnome_canvas_line_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	default:
 		break;
 	}
+
+	if (color_changed) {
+		if (have_pixel)
+			line->fill_pixel = color.pixel;
+		else
+			line->fill_pixel = gnome_canvas_get_color_pixel (item->canvas,
+									 line->fill_rgba);
+
+		if (item->canvas->aa)
+			set_line_gc_foreground (line);
+
+		gnome_canvas_item_request_redraw_svp (item, line->fill_svp);
+	}
 }
 
 static void
@@ -844,7 +858,6 @@ gnome_canvas_line_render (GnomeCanvasItem *item,
 			     GnomeCanvasBuf *buf)
 {
 	GnomeCanvasLine *line;
-	guint32 fg_color, bg_color;
 
 	line = GNOME_CANVAS_LINE (item);
 
@@ -932,10 +945,10 @@ gnome_canvas_line_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_pa
 			width = line->width;
 		else
 			width = line->width * art_affine_expansion (affine);
-		
+
 		if (width < 0.5)
 			width = 0.5;
-		
+
 		svp = art_svp_vpath_stroke (vpath,
 					    gnome_canvas_join_gdk_to_art (line->join),
 					    gnome_canvas_cap_gdk_to_art (line->cap),
@@ -1034,7 +1047,7 @@ item_to_canvas (GnomeCanvas *canvas, double *item_coords, GdkPoint *canvas_coord
 	old_cx = cx;
 	old_cy = cy;
 	*num_drawn_points = 1;
-	
+
 	for (i = 1; i < num_points; i++) {
 		pi.x = item_coords[i * 2];
 		pi.y = item_coords[i * 2 + 1];
@@ -1046,7 +1059,7 @@ item_to_canvas (GnomeCanvas *canvas, double *item_coords, GdkPoint *canvas_coord
 			canvas_coords->y = cy;
 			old_cx = cx;
 			old_cy = cy;
-			canvas_coords++; 
+			canvas_coords++;
 			(*num_drawn_points)++;
 		}
 	}
@@ -1164,7 +1177,7 @@ gnome_canvas_line_point (GnomeCanvasItem *item, double x, double y,
 		    || ((line->join == GDK_JOIN_ROUND) && (i != num_points))) {
 			dx = coords[0] - x;
 			dy = coords[1] - y;
-			dist = hypot(dx, dy) - width / 2.0;
+			dist = sqrt (dx * dx + dy * dy) - width / 2.0;
 			if (dist < GNOME_CANVAS_EPSILON) {
 				best = 0.0;
 				goto done;
@@ -1246,7 +1259,7 @@ gnome_canvas_line_point (GnomeCanvasItem *item, double x, double y,
 	if (line->cap == GDK_CAP_ROUND) {
 		dx = coords[0] - x;
 		dy = coords[1] - y;
-		dist = hypot(dx, dy) - width / 2.0;
+		dist = sqrt (dx * dx + dy * dy) - width / 2.0;
 		if (dist < GNOME_CANVAS_EPSILON) {
 			best = 0.0;
 			goto done;
