@@ -273,7 +273,6 @@ set_outline_gc_width (GnomeCanvasRE *re)
 				    GDK_LINE_SOLID, GDK_CAP_PROJECTING, GDK_JOIN_MITER);
 }
 
-
 static void
 gnome_canvas_re_set_fill (GnomeCanvasRE *re, gboolean fill_set)
 {
@@ -297,11 +296,13 @@ gnome_canvas_re_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	GnomeCanvasItem *item;
 	GnomeCanvasRE *re;
-	GdkColor color;
-	GdkColor *colorp;
+	GdkColor color = { 0, 0, 0, 0, };
+	GdkColor *pcolor;
+	int have_pixel;
 
 	item = GNOME_CANVAS_ITEM (object);
 	re = GNOME_CANVAS_RE (object);
+	have_pixel = FALSE;
 
 	switch (arg_id) {
 	case ARG_X1:
@@ -329,111 +330,121 @@ gnome_canvas_re_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		break;
 
 	case ARG_FILL_COLOR:
-		if (gnome_canvas_get_color (item->canvas, GTK_VALUE_STRING (*arg), &color)) {
-			gnome_canvas_re_set_fill (re, TRUE);
-			re->fill_pixel = color.pixel;
-			if (item->canvas->aa) {
-				re->fill_color =
-					((color.red & 0xff00) << 16) |
-					((color.green & 0xff00) << 8) |
-					(color.blue & 0xff00) |
-					0xff;
-#ifdef VERBOSE			       
-				g_print ("re fill color = %08x\n", re->fill_color);
-#endif
-			}
-			else
-				set_gc_foreground (re->fill_gc, re->fill_pixel);
-		} else {
-			gnome_canvas_re_set_fill (re, FALSE);
-			re->fill_color = 0;
-		}
-
-		gnome_canvas_item_request_redraw_svp (item, re->fill_svp);
-		break;
-
 	case ARG_FILL_COLOR_GDK:
-		gnome_canvas_re_set_fill (re, TRUE);
-		colorp = (GdkColor *) GTK_VALUE_BOXED (*arg);
-		re->fill_pixel = colorp->pixel;
+	case ARG_FILL_COLOR_RGBA:
+		switch (arg_id) {
+		case ARG_FILL_COLOR:
+			if (GTK_VALUE_STRING (*arg) &&
+			    gdk_color_parse (GTK_VALUE_STRING (*arg), &color))
+				gnome_canvas_re_set_fill (re, TRUE);
+			else
+				gnome_canvas_re_set_fill (re, FALSE);
 
-		if (item->canvas->aa)
-			re->fill_color = (((colorp->red & 0xff00) << 16) |
-					  ((colorp->green & 0xff00) << 8) |
-					  (colorp->blue & 0xff00) |
+			re->fill_color = ((color.red & 0xff00) << 16 |
+					  (color.green & 0xff00) << 8 |
+					  (color.blue & 0xff00) |
 					  0xff);
+			break;
+
+		case ARG_FILL_COLOR_GDK:
+			pcolor = GTK_VALUE_BOXED (*arg);
+			gnome_canvas_re_set_fill (re, pcolor != NULL);
+
+			if (pcolor) {
+				color = *pcolor;
+				gdk_color_context_query_color (item->canvas->cc, &color);
+				have_pixel = TRUE;
+			}
+
+			re->fill_color = ((color.red & 0xff00) << 16 |
+					  (color.green & 0xff00) << 8 |
+					  (color.blue & 0xff00) |
+					  0xff);
+			break;
+
+		case ARG_FILL_COLOR_RGBA:
+			gnome_canvas_re_set_fill (re, TRUE);
+			re->fill_color = GTK_VALUE_UINT (*arg);
+			break;
+		}
+#ifdef VERBOSE
+		g_print ("re fill color = %08x\n", re->fill_color);
+#endif
+		if (have_pixel)
+			re->fill_pixel = color.pixel;
 		else
+			re->fill_pixel = gnome_canvas_get_color_pixel (item->canvas, re->fill_color);
+
+		if (!item->canvas->aa)
 			set_gc_foreground (re->fill_gc, re->fill_pixel);
 
 		gnome_canvas_item_request_redraw_svp (item, re->fill_svp);
 		break;
 
-	case ARG_FILL_COLOR_RGBA:
-		gnome_canvas_re_set_fill (re, TRUE);
-		re->fill_set = TRUE;
-		re->fill_color = GTK_VALUE_UINT (*arg);
-
-		gnome_canvas_item_request_redraw_svp (item, re->fill_svp);
-		break;
-
 	case ARG_OUTLINE_COLOR:
-		if (gnome_canvas_get_color (item->canvas, GTK_VALUE_STRING (*arg), &color)) {
-#ifdef VERBOSE
-			g_print ("re outline color %x %x %x\n", color.red, color.green, color.blue);
-#endif
-			gnome_canvas_re_set_outline (re, TRUE);
-			re->outline_pixel = color.pixel;
-			if (item->canvas->aa)
-				re->outline_color =
-					((color.red & 0xff00) << 16) |
-					((color.green & 0xff00) << 8) |
-					(color.blue & 0xff00) |
-					0xff;
-			else
-				set_gc_foreground (re->outline_gc, re->outline_pixel);
-		} else {
-			gnome_canvas_re_set_outline (re, FALSE);
-			re->outline_color = 0;
-		}
-
-		gnome_canvas_item_request_redraw_svp (item, re->outline_svp);
-		break;
-
 	case ARG_OUTLINE_COLOR_GDK:
-		gnome_canvas_re_set_outline (re, TRUE);
-		colorp = (GdkColor *) GTK_VALUE_BOXED (*arg);
-		re->outline_set = TRUE;
-		re->outline_pixel = colorp->pixel;
+	case ARG_OUTLINE_COLOR_RGBA:
+		switch (arg_id) {
+		case ARG_OUTLINE_COLOR:
+			if (GTK_VALUE_STRING (*arg) &&
+			    gdk_color_parse (GTK_VALUE_STRING (*arg), &color))
+				gnome_canvas_re_set_outline (re, TRUE);
+			else
+				gnome_canvas_re_set_outline (re, FALSE);
 
-		if (item->canvas->aa)
-			re->outline_color = (((colorp->red & 0xff00) << 16) |
-					     ((colorp->green & 0xff00) << 8) |
-					     (colorp->blue & 0xff00) |
+			re->outline_color = ((color.red & 0xff00) << 16 |
+					     (color.green & 0xff00) << 8 |
+					     (color.blue & 0xff00) |
 					     0xff);
+			break;
+
+		case ARG_OUTLINE_COLOR_GDK:
+			pcolor = GTK_VALUE_BOXED (*arg);
+			gnome_canvas_re_set_outline (re, pcolor != NULL);
+
+			if (pcolor) {
+				color = *pcolor;
+				gdk_color_context_query_color (item->canvas->cc, &color);
+				have_pixel = TRUE;
+			}
+
+			re->outline_color = ((color.red & 0xff00) << 16 |
+					     (color.green & 0xff00) << 8 |
+					     (color.blue & 0xff00) |
+					     0xff);
+			break;
+
+		case ARG_OUTLINE_COLOR_RGBA:
+			gnome_canvas_re_set_outline (re, TRUE);
+			re->outline_color = GTK_VALUE_UINT (*arg);
+			break;
+		}
+#ifdef VERBOSE
+		g_print ("re outline color %x %x %x\n", color.red, color.green, color.blue);
+#endif
+		if (have_pixel)
+			re->outline_pixel = color.pixel;
 		else
+			re->outline_pixel = gnome_canvas_get_color_pixel (item->canvas,
+									  re->outline_color);
+
+		if (!item->canvas->aa)
 			set_gc_foreground (re->outline_gc, re->outline_pixel);
 
 		gnome_canvas_item_request_redraw_svp (item, re->outline_svp);
 		break;
 
-	case ARG_OUTLINE_COLOR_RGBA:
-		gnome_canvas_re_set_outline (re, TRUE);
-		re->outline_color = GTK_VALUE_UINT (*arg);
-
-		gnome_canvas_item_request_redraw_svp (item, re->outline_svp);
-
-		break;
-
 	case ARG_FILL_STIPPLE:
 		if (!item->canvas->aa)
 			set_stipple (re->fill_gc, &re->fill_stipple, GTK_VALUE_BOXED (*arg), FALSE);
+
 		break;
 
 	case ARG_OUTLINE_STIPPLE:
 		if (!item->canvas->aa)
 			set_stipple (re->outline_gc, &re->outline_stipple, GTK_VALUE_BOXED (*arg), FALSE);
 		break;
-		
+
 	case ARG_WIDTH_PIXELS:
 		re->width = GTK_VALUE_UINT (*arg);
 		re->width_pixels = TRUE;
@@ -441,7 +452,6 @@ gnome_canvas_re_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 			set_outline_gc_width (re);
 
 		gnome_canvas_item_request_update (item);
-	
 		break;
 
 	case ARG_WIDTH_UNITS:
@@ -451,7 +461,6 @@ gnome_canvas_re_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 			set_outline_gc_width (re);
 
 		gnome_canvas_item_request_update (item);
-
 		break;
 
 	default:
@@ -546,7 +555,7 @@ gnome_canvas_re_update_shared (GnomeCanvasItem *item, double *affine, ArtSVP *cl
 		set_stipple (re->fill_gc, &re->fill_stipple, re->fill_stipple, TRUE);
 		set_stipple (re->outline_gc, &re->outline_stipple, re->outline_stipple, TRUE);
 		set_outline_gc_width (re);
-	} 
+	}
 
 #ifdef OLD_XFORM
 	recalc_bounds (re);
@@ -644,7 +653,6 @@ gnome_canvas_re_render (GnomeCanvasItem *item,
 			GnomeCanvasBuf *buf)
 {
 	GnomeCanvasRE *re;
-	guint32 fg_color, bg_color;
 
 	re = GNOME_CANVAS_RE (item);
 
@@ -734,7 +742,7 @@ gnome_canvas_rect_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int
 	y1 = c1.y;
 	x2 = c2.x;
 	y2 = c2.y;
-	
+
 	if (re->fill_set) {
 		if (re->fill_stipple)
 			gnome_canvas_set_stipple_origin (item->canvas, re->fill_gc);
@@ -841,7 +849,7 @@ gnome_canvas_rect_point (GnomeCanvasItem *item, double x, double y, int cx, int
 	else
 		dy = 0.0;
 
-	return hypot(dx, dy);
+	return sqrt (dx * dx + dy * dy);
 }
 
 static void
@@ -1053,11 +1061,11 @@ gnome_canvas_ellipse_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x,
 	y1 = c1.y;
 	x2 = c2.x;
 	y2 = c2.y;
-	
+
 	if (re->fill_set) {
 		if (re->fill_stipple)
 			gnome_canvas_set_stipple_origin (item->canvas, re->fill_gc);
-		
+
 		gdk_draw_arc (drawable,
 			      re->fill_gc,
 			      TRUE,
@@ -1115,11 +1123,11 @@ gnome_canvas_ellipse_point (GnomeCanvasItem *item, double x, double y, int cx, i
 
 	dx = x - (re->x1 + re->x2) / 2.0;
 	dy = y - (re->y1 + re->y2) / 2.0;
-	center_dist = hypot(dx, dy);
+	center_dist = sqrt (dx * dx + dy * dy);
 
 	a = dx / ((re->x2 + width - re->x1) / 2.0);
 	b = dy / ((re->y2 + width - re->y1) / 2.0);
-	scaled_dist = hypot(a, b);
+	scaled_dist = sqrt (a * a + b * b);
 
 	/* If the scaled distance is greater than 1, then we are outside.  Compute the distance from
 	 * the point to the edge of the circle, then scale back to the original un-scaled coordinate
