@@ -485,12 +485,17 @@ gnome_canvas_text_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	GnomeCanvasItem *item;
 	GnomeCanvasText *text;
-	GdkColor color;
-	GdkColor *colorp;
+	GdkColor color = { 0, 0, 0, 0, };
+	GdkColor *pcolor;
+	gboolean color_changed;
+	int have_pixel;
 
 	item = GNOME_CANVAS_ITEM (object);
 	text = GNOME_CANVAS_TEXT (object);
 
+	color_changed = FALSE;
+	have_pixel = FALSE;
+
 	switch (arg_id) {
 	case ARG_TEXT:
 		if (text->text)
@@ -600,45 +605,34 @@ gnome_canvas_text_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		recalc_bounds (text);
 		break;
 
-	case ARG_FILL_COLOR:
-		if (gnome_canvas_get_color (item->canvas, GTK_VALUE_STRING (*arg), &color)) {
-			text->pixel = color.pixel;
-			if (item->canvas->aa)
-				text->rgba =
-					((color.red & 0xff00) << 16) |
-					((color.green & 0xff00) << 8) |
-					(color.blue & 0xff00) |
-					0xff;
-			else
-				set_text_gc_foreground (text);
-		} else {
-			text->pixel = 0;
-			if (item->canvas->aa)
-				text->rgba = 0;
-			else
-				set_text_gc_foreground (text);
-		}
-
+        case ARG_FILL_COLOR:
+		if (GTK_VALUE_STRING (*arg))
+			gdk_color_parse (GTK_VALUE_STRING (*arg), &color);
+		text->rgba = ((color.red & 0xff00) << 16 |
+			      (color.green & 0xff00) << 8 |
+			      (color.blue & 0xff00) |
+			      0xff);
+		color_changed = TRUE;
 		break;
 
 	case ARG_FILL_COLOR_GDK:
-		colorp = (GdkColor *) GTK_VALUE_BOXED (*arg);
-		text->pixel = colorp->pixel;
-		if (item->canvas->aa)
-			text->rgba = (((colorp->red & 0xff00) << 16) |
-				      ((colorp->green & 0xff00) << 8) |
-				      (colorp->blue & 0xff00) |
-				      0xff);
-		else
-			set_text_gc_foreground (text);
+		pcolor = GTK_VALUE_BOXED (*arg);
+		if (pcolor) {
+			color = *pcolor;
+			gdk_color_context_query_color (item->canvas->cc, &color);
+			have_pixel = TRUE;
+		}
+
+		text->rgba = ((color.red & 0xff00) << 16 |
+			      (color.green & 0xff00) << 8 |
+			      (color.blue & 0xff00) |
+			      0xff);
+		color_changed = TRUE;
 		break;
 
-	case ARG_FILL_COLOR_RGBA:
+        case ARG_FILL_COLOR_RGBA:
 		text->rgba = GTK_VALUE_UINT (*arg);
-
-		/* should probably request repaint on the fill_svp */
-		gnome_canvas_item_request_update (item);
-
+		color_changed = TRUE;
 		break;
 
 	case ARG_FILL_STIPPLE:
@@ -648,6 +642,18 @@ gnome_canvas_text_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	default:
 		break;
 	}
+
+	if (color_changed) {
+		if (have_pixel)
+			text->pixel = color.pixel;
+		else
+			text->pixel = gnome_canvas_get_color_pixel (item->canvas, text->rgba);
+
+		if (item->canvas->aa)
+			set_text_gc_foreground (text);
+
+		gnome_canvas_item_request_update (item);
+	}
 }
 
 static void
@@ -1023,7 +1029,7 @@ gnome_canvas_text_point (GnomeCanvasItem *item, double x, double y,
 		if ((dx == 0) && (dy == 0))
 			return 0.0;
 
-		dist = hypot(dx, dy);
+		dist = sqrt (dx * dx + dy * dy);
 		if (dist < best)
 			best = dist;
 
@@ -1106,7 +1112,7 @@ gnome_canvas_text_point (GnomeCanvasItem *item, double x, double y,
 		if ((dx == 0) && (dy == 0))
 			return 0.0;
 
-		dist = hypot(dx, dy);
+		dist = sqrt (dx * dx + dy * dy);
 		if (dist < best)
 			best = dist;
 
