@@ -889,7 +889,8 @@ client_parse_func (poptContext ctx,
 /**
  * gnome_client_disable_master_connection
  *
- * Description:
+ * Description: Don't connect the master client to the session manager. Usually 
+ * invoked by users when they pass the --sm-disable argument to a Gnome application.
  **/
 
 void         
@@ -1003,9 +1004,21 @@ gnome_client_init (void)
 /**
  * gnome_master_client
  *
- * Description:
- *
- * Returns:  Pointer to
+ * Description: 
+ * Get the master session management client.  This master client gets
+   a client id, that may be specified by the '--sm-client-id' command
+   line option.  A master client will be generated by 'gnome-init'.
+   If possible the master client will contact the session manager
+   after command-line parsing is finished (unless
+   'gnome_client_disable_master_connection' was called).  The master
+   client will also set the SM_CLIENT_ID property on the client leader
+   window of your application.  
+
+   Additionally, the master client gets some static arguments set
+   automatically (see 'gnome_client_add_static_arg' for static
+   arguments): 'gnome_init' passes all the command line options which 
+   are recognised by gtk as static arguments to the master client.
+ * Returns:  Pointer to the master client
  **/
 
 GnomeClient*
@@ -1219,7 +1232,8 @@ gnome_real_client_destroy (GtkObject *object)
  *
  * Description: Allocates memory for a new GNOME session management
  * client object.  After allocating, the client tries to connect to a
- * session manager.
+ * session manager. You probably want to use
+ * <function>gnome_master_client()</function> instead.
  *
  * Returns: Pointer to a newly allocated GNOME session management
  * client object.
@@ -1242,7 +1256,8 @@ gnome_client_new (void)
  * gnome_client_new_without_connection
  *
  * Description: Allocates memory for a new GNOME session management
- * client object.
+ * client object. You probably want to use
+ * <function>gnome_master_client()</function> instead.
  *
  * Returns: Pointer to a newly allocated GNOME session management
  * client object.
@@ -1304,7 +1319,8 @@ gnome_client_flush (GnomeClient *client)
  * gnome_client_connect
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Causes the client to connect to the session manager.
+ * Usually happens automatically; no need to call this function.
  **/
 
 void
@@ -1381,7 +1397,7 @@ gnome_client_connect (GnomeClient *client)
  * gnome_client_disconnect
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Disconnect the client from the session manager.
  **/
 
 void
@@ -1454,10 +1470,10 @@ gnome_client_get_flags (GnomeClient *client)
 /**
  * gnome_client_set_clone_command
  * @client: Pointer to GNOME session client object.
- * @argc:
- * @argv[]:
+ * @argc: number of strings in the argv vector
+ * @argv[]: argument strings, suitable for use with <function>execv()</function>
  *
- * Description:
+ * Description: Set a command the session manager can use to create a new instance of the application.
  **/
 
 void 
@@ -1479,9 +1495,9 @@ gnome_client_set_clone_command (GnomeClient *client,
 /**
  * gnome_client_set_current_directory
  * @client: Pointer to GNOME session client object.
- * @dir:
+ * @dir: Directory path
  *
- * Description:
+ * Description: Set the directory to be in when running shutdown, discard, restart, etc. commands.
  **/
 
 void 
@@ -1515,10 +1531,21 @@ gnome_client_set_current_directory (GnomeClient *client,
 /**
  * gnome_client_set_discard_command
  * @client: Pointer to GNOME session client object.
- * @argc:
- * @argv[]:
+ * @argc: Number of strings in argv
+ * @argv[]: Vector of strings such as those passed to <function>execv()</function>
  *
- * Description:
+ * Description: Provides a command to run when a client is removed
+ * from the session. It might delete session-specific config files for
+ * example.  Executing the discard command on the local host should
+ * delete the information saved as part of the session save that was
+ * in progress when the discard command was set. For example:
+
+<example>
+     gchar *prefix = gnome_client_get_config_prefix (client);
+     gchar *argv[] = { "rm", "-r", NULL };
+     argv[2] = gnome_config_get_real_path (prefix);
+     gnome_client_set_discard_command (client, 3, argv);
+</example>
  **/
 
 void 
@@ -1555,10 +1582,11 @@ gnome_client_set_discard_command (GnomeClient *client,
 /**
  * gnome_client_set_environment
  * @client: Pointer to GNOME session client object.
- * @name:
- * @value:
+ * @name: Name of the environment variable
+ * @value: Value of the environment variable
  *
- * Description:
+ * Description: Set an environment variable to be placed in the
+ * client's environment prior to running restart, shutdown, discard, etc. commands.
  **/
 
 void 
@@ -1608,9 +1636,11 @@ gnome_client_set_environment (GnomeClient *client,
 /**
  * gnome_client_set_process_id
  * @client: Pointer to GNOME session client object.
- * @pid:
+ * @pid: PID to set as the client's PID
  *
- * Description:
+ * Description: The client should tell the session manager the result
+ * of <function>getpid()</function>. However, Gnome does this
+ * automatically; so you don't need this function.
  **/
 
 void 
@@ -1635,9 +1665,10 @@ gnome_client_set_process_id (GnomeClient *client, pid_t pid)
 /**
  * gnome_client_set_program
  * @client: Pointer to GNOME session client object.
- * @program:
+ * @program: name of the program
  *
- * Description:
+ * Description: Used to tell the session manager the name of your program. Set automatically;
+ * this function isn't needed.
  **/
 
 void 
@@ -1666,10 +1697,19 @@ gnome_client_set_program (GnomeClient *client,
 /**
  * gnome_client_set_resign_command
  * @client: Pointer to GNOME session client object.
- * @argc:
- * @argv[]:
+ * @argc: number of strings in argv
+ * @argv[]: <function>execv()</function>-style command to undo the effects of the client.
  *
- * Description:
+ * Description: Some clients can be "undone," removing their effects and deleting any 
+ * saved state. For example, xmodmap could register a resign command to undo the keymap 
+ * changes it saved.
+ * 
+ * Used by clients that use the GNOME_RESTART_ANYWAY restart style to
+ * to undo their effects (these clients usually perform initialisation
+ * functions and leave effects behind after they die).  The resign
+ * command combines the effects of a shutdown command and a discard
+ * command. It is executed when the user decides that the client
+ * should cease to be restarted.
  **/
 
 void 
@@ -1706,10 +1746,15 @@ gnome_client_set_resign_command (GnomeClient *client,
 /**
  * gnome_client_set_restart_command
  * @client: Pointer to GNOME session client object.
- * @argc:
- * @argv[]:
+ * @argc: number of strings in argv
+ * @argv: argument vector to <function>execv()</function> to restart the client
  *
- * Description:
+ * Description: When clients crash or the user logs out and back in,
+   they are restarted.  * This command should perform the restart.  *
+   Executing the restart command on the local host should reproduce
+   the state of the client at the time of the session save as closely
+   as possible. Saving config info under the
+   gnome_client_get_config_prefix is generally useful.
  **/
 
 void 
@@ -1764,9 +1809,15 @@ gnome_client_set_priority (GnomeClient *client, guint priority)
 /**
  * gnome_client_set_restart_style
  * @client: Pointer to GNOME session client object.
- * @style:
+ * @style: When to restart the client
  *
- * Description:
+ * Description: GNOME_RESTART_IF_RUNNING causes the client to be
+ * restarted in the next session if it was running when the previous
+ * session exited. Restart is done via the restart command you
+ * set. GNOME_RESTART_ANYWAY means the client will be restarted even
+ * if the user exits the client before logging
+ * out. GNOME_RESTART_IMMEDIATELY restarts the client immediately
+ * anytime it crashes or is exited.
  **/
 
 void 
@@ -1815,10 +1866,17 @@ gnome_client_set_restart_style (GnomeClient *client,
 /**
  * gnome_client_set_shutdown_command
  * @client: Pointer to GNOME session client object.
- * @argc:
- * @argv[]:
+ * @argc: number of strings in argv
+ * @argv[]: command to shutdown the client if the client isn't running
  *
- * Description:
+ * Description: GNOME_RESTART_ANYWAY clients can set this command to run 
+ * when the user logs out but the client is no longer running.
+ *
+ * Used by clients that use the GNOME_RESTART_ANYWAY restart style to
+ * to undo their effects (these clients usually perform initialisation
+ * functions and leave effects behind after they die).  The shutdown
+ * command simply undoes the effects of the client. It is executed
+ * during a normal logout.
  **/
 
 void 
@@ -1855,13 +1913,14 @@ gnome_client_set_shutdown_command (GnomeClient *client,
 /**
  * gnome_client_set_user_id
  * @client: Pointer to GNOME session client object.
- * @id:
+ * @id: Username
  *
- * Description:
+ * Description: Tell the session manager the user's login name. Gnome
+ * does this automatically; no need to call the function.
  **/
 
 void 
-gnome_client_set_user_id (      GnomeClient *client,
+gnome_client_set_user_id (GnomeClient *client,
 			  const gchar       *id)
 {
   g_return_if_fail (client != NULL);
@@ -1883,9 +1942,15 @@ gnome_client_set_user_id (      GnomeClient *client,
 /**
  * gnome_client_add_static_arg
  * @client: Pointer to GNOME session client object.
- * @...:
+ * @...: NULL-terminated list of arguments to add to the restart command
  *
- * Description:
+ * Description: You can add arguments to your restart command argv
+   with this function. This function provides an alternative way of
+   adding new arguments to the restart command. The arguments are
+   placed before the arguments specified by
+   'gnome_client_set_restart_command' and after the arguments
+   recognised by gtk specified by the user on the original command
+   line.
  **/
 
 void
@@ -1913,9 +1978,11 @@ gnome_client_add_static_arg (GnomeClient *client, ...)
 /**
  * gnome_client_set_id
  * @client: Pointer to GNOME session client object.
- * @id:
+ * @id: Session management ID
  *
- * Description:
+ * Description: Set the client's session management ID; must be done
+ * before connecting to the session manager. Frankly I have no idea
+ * why you'd do this.
  **/
 
 void
@@ -1937,9 +2004,9 @@ gnome_client_set_id (GnomeClient *client, const gchar *id)
  * gnome_client_get_id
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Returns session management ID
  *
- * Returns:  Pointer to
+ * Returns:  Session management ID for this client; NULL if not connected to a session manager.
  **/
 
 gchar *
@@ -1955,9 +2022,10 @@ gnome_client_get_id (GnomeClient *client)
  * gnome_client_get_previous_id
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Get the previous session management ID (from previous session)
  *
- * Returns:  Pointer to
+ * Returns: Pointer to the session management ID the client had in the last
+ * session, or NULL if it wasn't in a previous session.
  **/
 
 gchar *
@@ -1973,9 +2041,14 @@ gnome_client_get_previous_id (GnomeClient *client)
  * gnome_client_get_config_prefix
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Get the config prefix for a client. This config prefix
+ * provides a suitable place to store any details about the state of
+ * the client which can not be described using the app's command line
+ * arguments (as set in the restart command). You may push the
+ * returned value using 'gnome_config_push_prefix' and read or write
+ *  any values you require.
  *
- * Returns:  Pointer to
+ * Returns: Config prefix.
  **/
 
 gchar *
@@ -2000,7 +2073,18 @@ static gchar* config_prefix = NULL;
  * @client: Pointer to GNOME session client object.
  * @prefix: Prefix for saving the global configuration
  *
- * Description:
+ * Description:  Set the value used for the global config prefix. The config prefixes 
+   returned by gnome_client_get_config_prefix are formed by extending
+   this prefix with an unique identifier.
+   
+   The global config prefix defaults to a name based on the name of
+   the executable. This function allows you to set it to a different
+   value. It should be called BEFORE retrieving the config prefix for
+   the first time. Later calls will be ignored.
+
+   For example, setting a global config prefix of "/app.d/session/"
+   would ensure that all your session save files or directories would
+   be gathered together into the app.d directory.
  **/
 
 void
@@ -2021,7 +2105,16 @@ gnome_client_set_global_config_prefix (GnomeClient *client, gchar* prefix)
  * gnome_client_get_global_config_prefix
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description: Get the config prefix that will be returned by
+ * <function>gnome_client_get_config_prefix()</function> for clients
+ * which have NOT been restarted or cloned (i.e. for clients started
+ * by the user without `--sm-' options). This config prefix may be
+ * used to write the user's preferred config for these "new" clients.
+ *
+ * You could also use this prefix as a place to store and retrieve
+ * config details that you wish to apply to ALL instances of the
+ * app. However, this practice limits the users freedom to configure
+ * each instance in a different way so it should be used with caution.
  *
  * Returns:  Pointer to
  **/
@@ -2317,11 +2410,19 @@ gnome_client_save_error_dialog (GnomeClient *client, GnomeDialog *dialog)
 /**
  * gnome_client_request_interaction
  * @client: Pointer to GNOME session client object.
- * @dialog_type:
- * @function:
- * @data:
+ * @dialog_type: What sort of dialog to create
+ * @function: Callback to invoke to perform the interaction
+ * @data: callback data
  *
- * Description:
+ * Description: Use the following functions, if you want to interact
+ * with the user during a "save_yourself" handler without being
+ * restricted to using the dialog based commands
+ * gnome_client_save_[any/error]_dialog.  If and when the session
+ * manager decides that it's the app's turn to interact then 'func'
+ * will be called with the specified arguments and a unique
+ * 'GnomeInteractionKey'. The session manager will block other clients
+ * from interacting until this key is returned with
+ * 'gnome_interaction_key_return'.
  **/
 
 void
@@ -2348,12 +2449,12 @@ gnome_client_request_interaction (GnomeClient *client,
 /**
  * gnome_client_request_interaction_interp
  * @client: Pointer to GNOME session client object.
- * @dialog_type:
- * @function:
- * @data:
- * @destroy:
+ * @dialog_type: Type of dialog to show
+ * @function: callback to perform the interaction
+ * @data: callback data
+ * @destroy: function to destroy callback data
  *
- * Description:
+ * Description: Used when you need to destroy the callback data after the interaction.
  **/
 
 void
@@ -2387,7 +2488,11 @@ gnome_client_request_interaction_interp (GnomeClient *client,
  * gnome_client_request_phase_2
  * @client: Pointer to GNOME session client object.
  *
- * Description:
+ * Description:  Request the session managaer to emit the "save_yourself" signal for 
+   a second time after all the clients in the session have ceased 
+   interacting with the user and entered an idle state. This might be 
+   useful if your app manages other apps and requires that they are in 
+   an idle state before saving its final data.
  **/
 
 void
@@ -2406,13 +2511,26 @@ gnome_client_request_phase_2 (GnomeClient *client)
 /**
  * gnome_client_request_save
  * @client: Pointer to GNOME session client object.
- * @save_style:
- * @shutdown:
- * @interact_style:
- * @fast:
- * @global:
+ * @save_style: Save style to request
+ * @shutdown: Whether to log out of the session
+ * @interact_style: whether to allow user interaction
+ * @fast: minimize activity to save ASAP
+ * @global: request that all other apps in the session also save
+ *
+ * Description: Request the session manager to save the session in
+ * some way. The arguments correspond with the arguments passed to the
+ * "save_yourself" signal handler.
+ *
+ * The save_style indicates whether the save should affect data
+ * accessible to other users (GNOME_SAVE_GLOBAL) or only the state
+ * visible to the current user (GNOME_SAVE_LOCAL) or both. Setting
+ * shutdown to TRUE will initiate a logout. The interact_style
+ * specifies which kinds of interaction will be available. Setting
+ * fast to TRUE will limit the save to setting the session manager
+ * properties plus any essential data.  Setting the value of global to
+ * TRUE will request that all the other apps in the session do a save
+ * as well. A global save is mandatory when doing a shutdown.
  *
- * Description:
  **/
 
 void
@@ -2550,10 +2668,11 @@ gnome_client_request_save (GnomeClient	       *client,
 
 /**
  * gnome_interaction_key_return
- * @key:
- * @cancel_shutdown:
+ * @key: Key passed to interaction callback
+ * @cancel_shutdown: if TRUE then cancel the shutdown
  *
- * Description:
+ * Description: Used in interaction callback to tell the session manager
+ * you're done interacting
  **/
 
 void
