@@ -29,6 +29,7 @@ struct _GnomeEntry {
 	int    changed;
 	char  *history_id;
 	GList *items;
+	guint  max_saved;
 };
 
 struct _GnomeEntryClass {
@@ -37,12 +38,14 @@ struct _GnomeEntryClass {
 
 
 guint      gnome_entry_get_type        (void);
-GtkWidget *gnome_entry_new             (char *history_id);
+GtkWidget *gnome_entry_new             (const gchar *history_id);
 
 GtkWidget *gnome_entry_gtk_entry       (GnomeEntry *gentry);
-void       gnome_entry_set_history_id  (GnomeEntry *gentry, char *history_id);
-void       gnome_entry_prepend_history (GnomeEntry *gentry, int save, char *text);
-void       gnome_entry_append_history  (GnomeEntry *gentry, int save, char *text);
+void       gnome_entry_set_history_id  (GnomeEntry *gentry, const gchar *history_id);
+void	   gnome_entry_set_max_saved   (GnomeEntry *gentry, guint max_saved);
+
+void       gnome_entry_prepend_history (GnomeEntry *gentry, gint save, const gchar *text);
+void       gnome_entry_append_history  (GnomeEntry *gentry, gint save, const gchar *text);
 void       gnome_entry_load_history    (GnomeEntry *gentry);
 void       gnome_entry_save_history    (GnomeEntry *gentry);
 
