@@ -133,6 +133,7 @@ BEGIN_GNOME_DECLS
 #define GNOME_STOCK_PIXMAP_LINE_IN     "Line In"
 #define GNOME_STOCK_PIXMAP_CDROM       "Cdrom"
 #define GNOME_STOCK_PIXMAP_VOLUME      "Volume"
+#define GNOME_STOCK_PIXMAP_MIDI        "Midi"
 #define GNOME_STOCK_PIXMAP_BOOK_RED    "Book Red"
 #define GNOME_STOCK_PIXMAP_BOOK_GREEN  "Book Green"
 #define GNOME_STOCK_PIXMAP_BOOK_BLUE   "Book Blue"
@@ -489,8 +490,9 @@ GtkWidget             *gnome_stock_or_ordinary_button (const char *type);
 #define GNOME_STOCK_MENU_SPELLCHECK   "Menu_Spellchecker"
 #define GNOME_STOCK_MENU_MIC          "Menu_Microphone"
 #define GNOME_STOCK_MENU_LINE_IN      "Menu_Line In"
-#define GNOME_STOCK_MENU_CDROM	      "Menu_Cdrom"
+#define GNOME_STOCK_MENU_CDROM	     "Menu_Cdrom"
 #define GNOME_STOCK_MENU_VOLUME       "Menu_Volume"
+#define GNOME_STOCK_MENU_MIDI         "Menu_Midi"
 #define GNOME_STOCK_MENU_BOOK_RED     "Menu_Book Red"
 #define GNOME_STOCK_MENU_BOOK_GREEN   "Menu_Book Green"
 #define GNOME_STOCK_MENU_BOOK_BLUE    "Menu_Book Blue"
