@@ -84,10 +84,11 @@ typedef struct {
 				    const char **params,
 				    gpointer *impl_ptr,
 				    CORBA_Environment *ev);
+
 	void         (*deactivate) (PortableServer_POA poa,
 				    const char *goad_id,
 				    gpointer impl_ptr,
-				    CORBA_Environment *ev);
+				    CORBA_Environment *ev); /* Not used - make it NULL */
 } GnomePluginObject;
 
 typedef struct {
@@ -95,6 +96,8 @@ typedef struct {
 	const char *description;
 } GnomePlugin;
 
+void gnome_plugin_unuse(gpointer impl_ptr);
+
 /**** goad module ****/
 typedef enum {
 	GOAD_SERVER_SHLIB = 1,
