@@ -35,6 +35,7 @@ static const gchar *authors[] = {
 	"Eckehard Berns",
 	"Havoc Pennington",
 	"Miguel de Icaza",
+	"Jonathan Blandford",
 	NULL
 };
 
@@ -229,91 +230,218 @@ create_color_picker (void)
 	gtk_widget_show (app);
 }
 
-static void guru_finish(GnomeGuru* guru, GtkWidget* destroyme)
+/*
+ * GnomeDruid
+ */
+
+
+typedef struct druid_data
 {
-  gnome_ok_dialog("Guru successfully completed, emitted 'finished'");
-  gtk_widget_destroy(destroyme);
+	GtkWidget *radio_button; /* if set, goto A, else goto b */
+	GtkWidget *target_a;
+	GtkWidget *target_b;
+} druid_data;
+
+static gboolean
+simple_druid_next_callback (GnomeDruidPage *page, GnomeDruid *druid, GnomeDruidPage *next)
+{
+	gtk_object_set_data (GTK_OBJECT (next), "back", page);
+	gnome_druid_set_page (druid,
+			      next);
+	return TRUE;
+}
+static gboolean
+complex_druid_next_callback (GnomeDruidPage *page, GnomeDruid *druid, druid_data *data)
+{
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->radio_button))) {
+		gtk_object_set_data (GTK_OBJECT (data->target_a), "back", page);
+		gnome_druid_set_page (druid,
+				      GNOME_DRUID_PAGE (data->target_a));
+	} else {
+		gtk_object_set_data (GTK_OBJECT (data->target_b), "back", page);
+		gnome_druid_set_page (druid,
+				      GNOME_DRUID_PAGE (data->target_b));
+	}
+	return TRUE;
+}
+static gboolean
+druid_back_callback (GnomeDruidPage *page, GnomeDruid *druid, gpointer data)
+{
+	GtkWidget *back_page = NULL;
+	back_page = gtk_object_get_data (GTK_OBJECT (page), "back");
+	if (back_page) {
+		gtk_object_set_data (GTK_OBJECT (page), "back", NULL);
+		gnome_druid_set_page (druid,
+				      GNOME_DRUID_PAGE (back_page));
+		return TRUE;
+	}
+	return FALSE;
 }
 
-static void guru_cancel(GnomeGuru* guru, GtkWidget* destroyme)
+/*
+ * The Druid's control flow looks something like this:
+ *
+ * page_start -> page_a -> page_b -> page_d -> page_f -> page_finish
+ *                      |          \                  /
+ *                      |            page_e -> page_g
+ *                       \                  /
+ *                         page_c ----------
+ */
+static void
+create_druid(void)
 {
-  gnome_ok_dialog("Guru cancelled");
-  gtk_widget_destroy(destroyme);
+  GtkWidget *window;
+  GtkWidget *druid;
+  gchar *fname;
+  GtkWidget *page_start, *page_finish;
+  GtkWidget *page_a, *page_b, *page_c, *page_d, *page_e, *page_f, *page_g;
+  GdkImlibImage *logo = NULL;
+  GdkImlibImage *watermark = NULL;
+  GtkWidget *check_a, *check_b;
+  GSList *radio_group;
+  druid_data *data;
+
+  /* load the images */
+  fname = gnome_pixmap_file ("gnome-logo-icon.png");
+  if (fname)
+    logo = gdk_imlib_load_image (fname);
+  g_free (fname);
+
+#if 0
+  /* We really need a better image for this.  For now, it'll do */
+  fname = gnome_pixmap_file ("gnome-logo-large.png");
+  if (fname)
+    watermark = gdk_imlib_load_image (fname);
+  g_free (fname);
+#endif
+
+  /* The initial stuff */
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  druid = gnome_druid_new ();
+
+  /* The druid pages. */
+  page_start = gnome_druid_page_start_new_with_vals
+    ("Beginning of the DRUID",
+     "This is a Sample DRUID\nIt will walk you through absolutely nothing. (-:\n\nIt would be nice to have a watermark on the left.",
+     logo,
+     watermark);
+  page_a = gnome_druid_page_standard_new_with_vals ("Page A", logo);
+  page_b = gnome_druid_page_standard_new_with_vals ("Page B", logo);
+  page_c = gnome_druid_page_standard_new_with_vals ("Page C", logo);
+  page_d = gnome_druid_page_standard_new_with_vals ("Page D", logo);
+  page_e = gnome_druid_page_standard_new_with_vals ("Page E", logo);
+  page_f = gnome_druid_page_standard_new_with_vals ("Page F", logo);
+  page_g = gnome_druid_page_standard_new_with_vals ("Page G", logo);
+  page_finish = gnome_druid_page_finish_new_with_vals
+    ("End of the DRUID",
+     "I hope you found this demo informative.  You would\nnormally put a message here letting someone know\nthat they'd successfully installed something.",
+     logo,
+     watermark);
+
+  /* set each one up. */
+  /* page_a */
+  data = g_new (druid_data, 1);
+  radio_group = NULL;
+  check_a = gtk_radio_button_new_with_label (NULL, "Go to page B");
+  radio_group = gtk_radio_button_group (GTK_RADIO_BUTTON (check_a));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_a), TRUE);
+  check_b = gtk_radio_button_new_with_label (radio_group, "Go to page C");
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_a)->vbox),
+		      check_a, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_a)->vbox),
+		      check_b, FALSE, FALSE, 0);
+  data->radio_button = check_a;
+  data->target_a = page_b;
+  data->target_b = page_c;
+  gtk_signal_connect (GTK_OBJECT (page_a), "next", (GtkSignalFunc) complex_druid_next_callback, (gpointer) data);
+  gtk_signal_connect (GTK_OBJECT (page_a), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_b */
+  data = g_new (druid_data, 1);
+  radio_group = NULL;
+  check_a = gtk_radio_button_new_with_label (NULL, "Go to page D");
+  radio_group = gtk_radio_button_group (GTK_RADIO_BUTTON (check_a));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_a), TRUE);
+  check_b = gtk_radio_button_new_with_label (radio_group, "Go to page E");
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_b)->vbox),
+		      check_a, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_b)->vbox),
+		      check_b, FALSE, FALSE, 0);
+  data->radio_button = check_a;
+  data->target_a = page_d;
+  data->target_b = page_e;
+  gtk_signal_connect (GTK_OBJECT (page_b), "next", (GtkSignalFunc) complex_druid_next_callback, (gpointer) data);
+  gtk_signal_connect (GTK_OBJECT (page_b), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_c */
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_c)->vbox),
+		      gtk_label_new ("This page will take you to page G\nYou don't have any say in the matter. (-:"),
+		      FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (page_c), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_g);
+  gtk_signal_connect (GTK_OBJECT (page_c), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_d */
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_d)->vbox),
+		      gtk_label_new ("This page will take you to page F"),
+		      FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (page_d), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_f);
+    gtk_signal_connect (GTK_OBJECT (page_d), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_e */
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_e)->vbox),
+		      gtk_label_new ("This page will take you to page G\n\nShe sells sea shells by the sea shore."),
+		      FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (page_e), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_g);
+  gtk_signal_connect (GTK_OBJECT (page_e), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_f */
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_f)->vbox),
+		      gtk_label_new ("This is a second to last page.\nIt isn't as nice as page G.\n\nClick Next to go to the last page\n"),
+		      FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (page_f), "next", (GtkSignalFunc) simple_druid_next_callback, (gpointer) page_finish);
+  gtk_signal_connect (GTK_OBJECT (page_f), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /* page_g */
+  gtk_box_pack_start (GTK_BOX (GNOME_DRUID_PAGE_STANDARD (page_g)->vbox),
+		      gtk_label_new ("This is page G!!!!\n\nyay!!!!!!!"),
+		      FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (page_g), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+
+  /* page_finish */
+  gtk_signal_connect (GTK_OBJECT (page_finish), "back", (GtkSignalFunc) druid_back_callback, (gpointer) NULL);
+
+  /*Tie it together */
+  gtk_container_add (GTK_CONTAINER (window), druid);
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_start));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_a));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_b));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_c));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_d));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_e));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_f));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_g));
+  gnome_druid_append_page (GNOME_DRUID (druid),
+			   GNOME_DRUID_PAGE (page_finish));
+  gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (page_start));
+  gtk_widget_show_all (window);
 }
 
+/*
+ * GnomeGuru
+ */
 static void
 create_guru(void)
 {
-  /* We want to test both in a dialog, and without a dialog. */
-  GtkWidget* guru;
-  GtkWidget* page;
-  GtkWidget* dialog;
-  GtkWidget* graphic;
-  GtkWidget* window;
-  gchar* pix;
-
-  pix = gnome_pixmap_file("gnome-logo-large.png");
-  graphic = gnome_pixmap_new_from_file_at_size(pix, 100, 300);
-  g_free(pix);
-
-  guru = gnome_guru_new("Test Gnome Guru (without dialog)",
-			graphic,
-			NULL);
-
-  window = create_newwin(TRUE, "testGNOME", "Gnome Guru Test Window");
-
-  gnome_app_set_contents(GNOME_APP(window), guru);
-
-  page = gtk_label_new("Page one");
-  gnome_guru_append_page(GNOME_GURU(guru), "First page", page);
-  page = gtk_label_new("Page two");
-  gnome_guru_append_page(GNOME_GURU(guru), "Second page", page);
-  page = gtk_label_new("Page three");
-  gnome_guru_append_page(GNOME_GURU(guru), "Third page", page);
-  page = gtk_label_new("Page four");
-  gnome_guru_append_page(GNOME_GURU(guru), "Fourth page", page);
-
-  gtk_signal_connect(GTK_OBJECT(guru), "finished",
-		     GTK_SIGNAL_FUNC(guru_finish),
-		     window);
-
-  gtk_signal_connect(GTK_OBJECT(guru), "cancelled",
-		     GTK_SIGNAL_FUNC(guru_cancel),
-		     window);
-
-  gtk_widget_show(guru);
-  gtk_widget_show(window);
-
-  dialog = gnome_dialog_new(_("Guru-in-a-dialog test"),
-			    NULL);
-
-  pix = gnome_pixmap_file("gnome-logo-large.png");
-  graphic = gnome_pixmap_new_from_file_at_size(pix, 100, 300);
-  g_free(pix);
-
-  guru = gnome_guru_new("Test Gnome Guru (without dialog)",
-			graphic,
-			GNOME_DIALOG(dialog));
-
-  page = gtk_label_new("Page one");
-  gnome_guru_append_page(GNOME_GURU(guru), "First page", page);
-  page = gtk_label_new("Page two");
-  gnome_guru_append_page(GNOME_GURU(guru), "Second page", page);
-  page = gtk_label_new("Page three");
-  gnome_guru_append_page(GNOME_GURU(guru), "Third page", page);
-  page = gtk_label_new("Page four");
-  gnome_guru_append_page(GNOME_GURU(guru), "Fourth page", page);
-
-  gtk_signal_connect(GTK_OBJECT(guru), "finished",
-		     GTK_SIGNAL_FUNC(guru_finish),
-		     dialog);
-
-  gtk_signal_connect(GTK_OBJECT(guru), "cancelled",
-		     GTK_SIGNAL_FUNC(guru_cancel),
-		     dialog);
-
-  gtk_widget_show(guru);
-  gtk_widget_show(dialog);
+  gnome_ok_dialog("The Guru widget is deprecated.  Use the Druid instead.");
 }
 
 /*
@@ -745,6 +873,28 @@ create_font_picker (void)
 
 }
 
+static void
+select_icon (GnomeIconList *gil, gint n, GdkEvent *event, gpointer data)
+{
+	printf ("Icon %d selected", n);
+
+	if (event)
+		printf (" with event type %d\n", (int) event->type);
+	else
+		printf ("\n");
+}
+
+static void
+unselect_icon (GnomeIconList *gil, gint n, GdkEvent *event, gpointer data)
+{
+	printf ("Icon %d unselected", n);
+
+	if (event)
+		printf (" with event type %d\n", (int) event->type);
+	else
+		printf ("\n");
+}
+
 static void
 create_icon_list(void)
 {
@@ -759,11 +909,17 @@ create_icon_list(void)
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gnome_app_set_contents (GNOME_APP (app), sw);
-	gtk_widget_set_usize (sw, 200, 200);
+	gtk_widget_set_usize (sw, 430, 300);
 	gtk_widget_show (sw);
 
 	iconlist = gnome_icon_list_new (80, NULL, TRUE);
 	gtk_container_add (GTK_CONTAINER (sw), iconlist);
+	gtk_signal_connect (GTK_OBJECT (iconlist), "select_icon",
+			    GTK_SIGNAL_FUNC (select_icon),
+			    NULL);
+	gtk_signal_connect (GTK_OBJECT (iconlist), "unselect_icon",
+			    GTK_SIGNAL_FUNC (unselect_icon),
+			    NULL);
 
 	GTK_WIDGET_SET_FLAGS(iconlist, GTK_CAN_FOCUS);
 	pix = gdk_imlib_create_image_from_xpm_data((gchar **)bomb_xpm);
@@ -779,7 +935,7 @@ create_icon_list(void)
 		gnome_icon_list_append_imlib(GNOME_ICON_LIST(iconlist), pix, "LaLa");
 	}
 
-	gnome_icon_list_set_selection_mode (GNOME_ICON_LIST (iconlist), GTK_SELECTION_MULTIPLE);
+	gnome_icon_list_set_selection_mode (GNOME_ICON_LIST (iconlist), GTK_SELECTION_EXTENDED);
 	gnome_icon_list_thaw (GNOME_ICON_LIST (iconlist));
 	gtk_widget_show (iconlist);
 	gtk_widget_show(app);
@@ -805,7 +961,6 @@ static void
 create_pixmap(void)
 {
 	GtkWidget *app;
-	GdkImlibImage *pix;
 	GtkWidget *pixmap;
 	app = create_newwin(TRUE,"testGNOME","Pixmap");
 	pixmap = gnome_pixmap_new_from_xpm_d (bomb_xpm);
@@ -996,7 +1151,7 @@ percent_cb(gpointer ignore)
 }
 
 static void
-cancel_cb(gpointer ignore, GtkWidget *widget)
+cancel_cb(gpointer ignore)
 {
   gnome_ok_dialog("Progress cancelled!");
 }
@@ -1739,6 +1894,7 @@ main (int argc, char *argv[])
 		  { "canvas", create_canvas },
 		  { "clock",	create_clock },
 		  { "color picker", create_color_picker },
+		  { "druid", create_druid },
 		  { "guru", create_guru },
 		  { "paper-sel", create_papersel },
 		  { "date edit", create_date_edit },
