@@ -180,7 +180,9 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, struct vt_line *b
 	  vx->draw_text(vx->vt.user_data, bl,
 			line, runstart, run, attr);
 	  vx->back_match = always?0:
-	    ((VT_BMASK(newattr) == VT_BMASK(oldattr)) && VT_BLANK(oldchar&0xffff));
+	    ((VT_BMASK(newattr) == VT_BMASK(oldattr))
+	     && VT_BLANK(oldchar&0xffff)
+	     && (newattr&VTATTR_REVERSE)==0);
 	  run = 1;
 	  runstart = i;
 	  attr = newattr;
@@ -188,9 +190,11 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, struct vt_line *b
 	}
       } else {
 	vx->back_match = always?0:
-	  ((VT_BMASK(newattr) == VT_BMASK(oldattr)) && VT_BLANK(oldchar&0xffff));
+	  ((VT_BMASK(newattr) == VT_BMASK(oldattr))
+	   && VT_BLANK(oldchar&0xffff)
+	   && (newattr&VTATTR_REVERSE)==0);
 	runstart = i;
-	attr = newchar & VTATTR_MASK;
+	attr = newattr;
 	run=1;
 	commonrun = 0;
       }
@@ -374,7 +378,7 @@ static int vt_scroll_update(struct _vtx *vx, struct vt_line *fn, int firstline,
       d(printf("%p: line %d, was %d\n", nn, i, nn->line));
 
       if (nn==(struct vt_line *)vx->vt.scrollback.tailpred) {
-	d(printf("++ skipping to real lines at line %d\n", line));
+	d(printf("++ skipping to real lines at line %d\n", nn->line));
 	nn = (struct vt_line *)vx->vt.lines.head;
       } else {
 	d(printf("++ going to next line ...\n"));
@@ -400,7 +404,7 @@ static int vt_scroll_update(struct _vtx *vx, struct vt_line *fn, int firstline,
 	vt_line_update(vx, nn, bl, i, force, 0, bl->width);
 
 	if (nn==(struct vt_line *)vx->vt.scrollback.tailpred) {
-	  d(printf("++ skipping to real lines at line %d\n", line));
+	  d(printf("++ skipping to real lines at line %d\n", nn->line));
 	  nn = (struct vt_line *)vx->vt.lines.head;
 	} else {
 	  d(printf("++ going to next line ...\n"));
@@ -430,7 +434,7 @@ static int vt_scroll_update(struct _vtx *vx, struct vt_line *fn, int firstline,
 	d(printf("updating line %d\n", i));
 	vt_line_update(vx, nn, bl, i, force, 0, bl->width);
 	if (nn==(struct vt_line *)vx->vt.scrollback.tailpred) {
-	  d(printf("++ skipping to real lines at line %d\n", line));
+	  d(printf("++ skipping to real lines at line %d\n", nn->line));
 	  nn = (struct vt_line *)vx->vt.lines.head;
 	} else {
 	  d(printf("++ going to next line ...\n"));
@@ -799,6 +803,7 @@ static int vt_in_wordclass(struct _vtx *vx, uint32 c)
 {
   int ch;
 
+  c &= VTATTR_DATAMASK;
   if (c>=256)
     return 1;
   ch = c&0xff;
@@ -837,6 +842,7 @@ void vt_set_wordclass(struct _vtx *vx, unsigned char *s)
 	vx->wordclass[i>>3] |= 1<<(i&7);
       }
   }
+  d( printf("wordclass: "); for(i=0;i<sizeof(vx->wordclass);i++) printf("%2.2x", vx->wordclass[i]); printf("\n") );
 }
 
 
@@ -904,31 +910,30 @@ void vt_fix_selection(struct _vtx *vx)
     if (ex==sx && ex<e->width && sy==ey)
       ex++;
 
-    if ((s->data[sx]&0xff)==0 || (s->data[sx]&0xff)==9) {
-      while ((sx>0) && ((s->data[sx]&0xff) == 0))
+    if ((s->data[sx]&VTATTR_DATAMASK)==0 || (s->data[sx]&VTATTR_DATAMASK)==9) {
+      while ((sx>0) && ((s->data[sx]&VTATTR_DATAMASK) == 0))
 	sx--;
       if (sx &&
-	  ((s->data[sx])&0xff)!=0x09) /* 'compress' tabs */
+	  ((s->data[sx])&VTATTR_DATAMASK)!=0x09) /* 'compress' tabs */
 	sx++;
     } else {
       while ((sx>0) &&
 	     (( (vt_in_wordclass(vx, s->data[sx])))))
 	sx--;
-      if ((s->data[sx]&0xff)==0
-	  || (s->data[sx]&0xff)==9)
+      if (!vt_in_wordclass(vx, s->data[sx]))
 	sx++;
     }
     d(printf("%d\n", sx));
 
     /* scan forward over word chars */
     /* special cases for tabs and 'blank' character select */
-    if ( !((ex >0) && ((e->data[ex-1]&0xff) != 0)) )
-      while ((ex<e->width) && ((e->data[ex]&0xff) == 0))
-	ex++;
+    if ( !((ex >0) && ((e->data[ex-1]&VTATTR_DATAMASK) != 0)) )
+      while ((ex<e->width) && ((e->data[ex]&VTATTR_DATAMASK) == 0))
+  	ex++;
     if ( !((ex >0) && (!vt_in_wordclass(vx, e->data[ex-1]))) )
-      while ((ex<e->width) && 
+        while ((ex<e->width) && 
 	     ( (vt_in_wordclass(vx, e->data[ex]))))
-	ex++;
+  	ex++;
 
     break;
   case VT_SELTYPE_CHAR:
@@ -938,17 +943,17 @@ void vt_fix_selection(struct _vtx *vx)
     if (ex==sx && ex<e->width && sy==ey)
       ex++;
 
-    if ((s->data[sx]&0xff)==0) {
-      while ((sx>0) && ((s->data[sx]&0xff) == 0))
+    if ((s->data[sx]&VTATTR_DATAMASK)==0) {
+      while ((sx>0) && ((s->data[sx]&VTATTR_DATAMASK) == 0))
 	sx--;
       if (sx &&
-	  (( ((s->data[sx])&0xff)!=0x09))) /* 'compress' tabs */
+	  (( ((s->data[sx])&VTATTR_DATAMASK)!=0x09))) /* 'compress' tabs */
 	sx++;
     }
 
     /* special cases for tabs and 'blank' character select */
-    if ( !((ex >0) && ((e->data[ex-1]&0xff) != 0)) )
-      while ((ex<e->width) && ((e->data[ex]&0xff) == 0))
+    if ( !((ex >0) && ((e->data[ex-1]&VTATTR_DATAMASK) != 0)) )
+      while ((ex<e->width) && ((e->data[ex]&VTATTR_DATAMASK) == 0))
 	ex++;
   }
 
