@@ -58,48 +58,42 @@ child_died_event (ZvtTerm *term)
 static void
 title_changed_event (ZvtTerm *term, VTTITLE_TYPE type, char *newtitle)
 {
-  switch(type) 
-    {
-    case VTTITLE_WINDOW:
-    case VTTITLE_WINDOWICON:
-      gtk_window_set_title (GTK_WINDOW (window), newtitle);
-      break;
-    default:
-      break;
-    }
+  switch(type) {
+  case VTTITLE_WINDOW:
+  case VTTITLE_WINDOWICON:
+    gtk_window_set_title (GTK_WINDOW (window), newtitle);
+    break;
+  default:
+    break;
+  }
 }
 
 static void
-size_allocate (GtkWidget *widget)
+set_hints (GtkWidget *widget)
 {
-  ZvtTerm *term;
-  XSizeHints sizehints;
-  
-  g_assert (widget != NULL);
-  term = ZVT_TERM (widget);
+        ZvtTerm *term;
+	GdkGeometry hints;
+	GtkWidget *app;
 
-#define PADDING 2  
-  sizehints.base_width = 
-    (GTK_WIDGET (window)->allocation.width) +
-    (GTK_WIDGET (term)->style->klass->xthickness * 2) -
-    (GTK_WIDGET (term)->allocation.width) + PADDING;
-  
-  sizehints.base_height =
-    (GTK_WIDGET (window)->allocation.height) +
-    (GTK_WIDGET (term)->style->klass->ythickness * 2) -
-    (GTK_WIDGET (term)->allocation.height);
-  
-  sizehints.width_inc = term->charwidth;
-  sizehints.height_inc = term->charheight;
-  sizehints.min_width = sizehints.base_width + sizehints.width_inc;
-  sizehints.min_height = sizehints.base_height + sizehints.height_inc;
-  
-  sizehints.flags = (PBaseSize|PMinSize|PResizeInc);
-  
-  XSetWMNormalHints (GDK_DISPLAY(),
-		     GDK_WINDOW_XWINDOW (GTK_WIDGET (window)->window),
-		     &sizehints);
-  gdk_flush ();
+	g_assert (widget != NULL);
+	term = ZVT_TERM (widget);
+
+	app = gtk_widget_get_toplevel(widget);
+	g_assert (app != NULL);
+
+#define PADDING 2
+	hints.base_width = (GTK_WIDGET (term)->style->klass->xthickness * 2) + PADDING;
+	hints.base_height =  (GTK_WIDGET (term)->style->klass->ythickness * 2);
+
+	hints.width_inc = term->charwidth;
+	hints.height_inc = term->charheight;
+	hints.min_width = hints.base_width + hints.width_inc;
+	hints.min_height = hints.base_height + hints.height_inc;
+
+	gtk_window_set_geometry_hints(GTK_WINDOW(app),
+				      GTK_WIDGET(term),
+				      &hints,
+				      GDK_HINT_RESIZE_INC|GDK_HINT_MIN_SIZE|GDK_HINT_BASE_SIZE);
 }
 
 /*
@@ -111,7 +105,7 @@ gint
 main (gint argc, gchar *argv[])
 {
   int i, c, cmdindex, scrollbacklines, login_shell;
-  char buffer[60], **p;
+  char buffer[60], **p, *fontname=FONT;
   struct passwd *pw;
   GtkWidget *term, *hbox, *scrollbar;
   enum { RIGHT, LEFT } scrollpos = LEFT;
@@ -126,22 +120,15 @@ main (gint argc, gchar *argv[])
   for (p = env; *p; p++);
   i = p - env;
   env_copy = (char **) g_malloc (sizeof (char *) * (i + 3));
-  for (i = 0, p = env; *p; p++)
-    {
+  for (i = 0, p = env; *p; p++) {
       if (strncmp (*p, "TERM=", 5) == 0)
-	{
 	  env_copy [i++] = "TERM=xterm";
-	}
       else if ((strncmp (*p, "COLUMNS=", 8) == 0) ||
 	       (strncmp (*p, "LINES=", 6) == 0))
-	{
 	  continue;
-	} 
       else
-	{
 	  env_copy [i++] = *p;
-	}
-    }
+  }
 
   env_copy [i++] = "COLORTERM=zterm";
   winid_pos = i++;
@@ -151,34 +138,36 @@ main (gint argc, gchar *argv[])
   gtk_init(&argc, &argv);
 
   /* process arguments */
-  while ( (cmdindex==0) && (c=getopt(argc, argv, "le:s:rh")) != EOF )
-    {
-      switch(c) 
-	{
-	case 'e':
-	  cmdindex = optind-1;	/* index of argv array to pass to exec */
-	  break;
+  while ( (cmdindex==0) && (c=getopt(argc, argv, "le:s:rhf:")) != EOF ) {
+    switch(c) {
+    case 'e':
+      cmdindex = optind-1;	/* index of argv array to pass to exec */
+      break;
+      
+    case 's':
+      scrollbacklines = atoi(optarg);
+      break;
+      
+    case 'l':
+      login_shell = 1;
+      break;
+      
+    case 'r':
+      scrollpos = RIGHT;
+      break;
+      
+    case 'f':
+      fontname = optarg;
+      break;
 
-	case 's':
-	  scrollbacklines = atoi(optarg);
-	  break;
-
-	case 'l':
-	  login_shell = 1;
-	  break;
-
-	case 'r':
-	  scrollpos = RIGHT;
-	  break;
-
-	case '?':
-	case 'h':
-	default:
-	  fprintf(stderr, "Usage: zterm [-sNN] [-l] [-r] [-e command args]\n");
-	  exit(1);
-	  break;
-	}
+    case '?':
+    case 'h':
+    default:
+      fprintf(stderr, "Usage: zterm [-sNN] [-l] [-r] [-f fontname] [-e command args]\n");
+      exit(1);
+      break;
     }
+  }
 
   /* Create widgets and set options */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -195,7 +184,7 @@ main (gint argc, gchar *argv[])
 
   /* create terminal */
   term = zvt_term_new_with_size(80,24);
-  zvt_term_set_font_name(ZVT_TERM (term), FONT);
+  zvt_term_set_font_name(ZVT_TERM (term), fontname);
   zvt_term_set_blink (ZVT_TERM (term), TRUE);
   zvt_term_set_bell (ZVT_TERM (term), TRUE);
   zvt_term_set_scrollback(ZVT_TERM (term), scrollbacklines);
@@ -224,8 +213,8 @@ main (gint argc, gchar *argv[])
   
   gtk_signal_connect_after (
       GTK_OBJECT (term),
-      "size_allocate",
-      GTK_SIGNAL_FUNC (size_allocate),
+      "realize",
+      GTK_SIGNAL_FUNC (set_hints),
       term);
 
   gtk_widget_show (term);
@@ -247,62 +236,49 @@ main (gint argc, gchar *argv[])
   gtk_widget_show (window);
 
   /* fork the shell/program */
-  switch (zvt_term_forkpty(ZVT_TERM (term), ZVT_TERM_DO_UTMP_LOG | ZVT_TERM_DO_WTMP_LOG))
-    {
-    case -1:
-      perror("ERROR: unable to fork:");
-      exit(1);
-      break;
-
-    case 0:
-      if (cmdindex)
-	{
-	  environ = env_copy;
-	  execvp(argv[cmdindex], &argv[cmdindex]);
+  switch (zvt_term_forkpty(ZVT_TERM (term), ZVT_TERM_DO_UTMP_LOG | ZVT_TERM_DO_WTMP_LOG)) {
+  case -1:
+    perror("ERROR: unable to fork:");
+    exit(1);
+    break;
+    
+  case 0:
+    if (cmdindex) {
+      environ = env_copy;
+      execvp(argv[cmdindex], &argv[cmdindex]);
+    } else {
+      GString *shell, *name;
+      
+      /* get shell from passwd */
+      pw = getpwuid(getuid());
+      if (pw) {
+	shell = g_string_new(pw->pw_shell);
+	if (login_shell) {
+	  name = g_string_new("-");
+	} else {
+	  name = g_string_new("");
 	}
-      else
-	{
-	  GString *shell, *name;
-	  
-	  /* get shell from passwd */
-	  pw = getpwuid(getuid());
-	  if (pw)
-	    {
-	      shell = g_string_new(pw->pw_shell);
-	      if (login_shell)
-		{
-		  name = g_string_new("-");
-		}
-	      else
-		{
-		  name = g_string_new("");
-		}
 	      
-	      g_string_append(name, strrchr(pw->pw_shell, '/'));
-	    }
-	  else
-	    {
-	      shell = g_string_new("/bin/sh");
-	      if (login_shell)
-		{
-		  name = g_string_new("-sh");
-		}
-	      else
-		{
-		  name = g_string_new("sh");
-		}
-	    }
-
-	  execle (shell->str, name->str, NULL, env_copy);
-	  perror ("Could not exec\n");
-	  _exit (127);
+	g_string_append(name, strrchr(pw->pw_shell, '/'));
+      } else {
+	shell = g_string_new("/bin/sh");
+	if (login_shell) {
+	  name = g_string_new("-sh");
+	} else {
+	  name = g_string_new("sh");
 	}
-      perror("ERROR: Cannot exec command:");
-      exit(1);
-
-    default:
-      break;
+      }
+      
+      execle (shell->str, name->str, NULL, env_copy);
+      perror ("Could not exec\n");
+      _exit (127);
     }
+    perror("ERROR: Cannot exec command:");
+    exit(1);
+    
+  default:
+    break;
+  }
   
   /* main loop */
   gtk_main ();
